#!/etc/opt/openit/perl

# Fixes the issue in UCS 6.4.0.9 caused by a previous patch, concerning the Report filter definition for licenseevents-host-usage.conf
# Issue -- Report:individual-license-usage
# Should be -- Report:host-license-usage

my $version_file = "/var/opt/openit/inst/package/common.info";

open( IN, $version_file ) || die "ERROR: Can't find $version_file for server version checking!\n";

foreach my $version_line ( <IN> ) {
	if( $version_line =~ /VERSION/ ) {
		my @version_split = split / /, $version_line;
		if( $version_split[1] != "6.4.0.9" ) {
			print "Update is only needed for UCS 6.4.0.9; aborting script...\n";
			exit( 0 );
		}
	}
}

my $old_host_usage_conf = "/var/opt/openit/etc/filtrator/licenseevents-host-usage.conf";
my @new_lines;

open( IN, $old_host_usage_conf ) || die "ERROR: Unable to read licenseevents-host-usage.conf!\n";

my $filter_defs_scope = 0;
my $wrong_filter_def_fixed = 0;

my $concurrent_def_scope = 0;

foreach my $line ( <IN> ) {
	if( $line =~ /filter-defs/ ) {
		$filter_defs_scope = 1;
	}

	if( $filter_defs_scope and ! $wrong_filter_def_fixed and $line =~ /Report\:individual-license-usage/ ) {
		push @new_lines, "\t\tReport:host-license-usage()=\"\"\n";
		next;
	}

	if( $filter_defs_scope and $line =~ /Concurrent\:feature/ ) {
		$concurrent_def_scope = 1;
	}

	if( $filter_defs_scope and $concurrent_def_scope ) {
		if( $line =~ /keytype/ ) {
			next;
		}
		if( $line =~ /compare/ ) {
			$line =~ s/used_licenses,//g;
		}
		if( $line =~ /\t\t\}/ ) {
			$concurrent_def_scope = 0;
		}
	}

	push @new_lines, $line;
}

close( IN );

rename( $old_host_usage_conf, "$old_host_usage_conf.pre_2123" ) || die "ERROR: Unable to write new licenseevents-host-usage.conf file!\n";

open( OUT, ">/var/opt/openit/etc/filtrator/licenseevents-host-usage.conf" ) || die "ERROR: Unable to write new licenseevents-host-usage.conf file!\n";
print OUT @new_lines;
close( OUT );

exit( 0 ); 
