#!/etc/opt/openit/perl

# Fixes the issue in UCS 6.4.0.9 caused by a previous patch, concerning the Report filter definition for licenseevents-hostgroups.conf
# Issue -- Report:usergroup-license-usage
# Should be -- Report:hostgroup-license-usage
# Additional fix -- licenseevents-usergroups line changed to licenseevents-hostgroups

my $version_file = "/var/opt/openit/inst/package/common.info";

open( IN, $version_file ) || die "ERROR: Can't find $version_file for server version checking!\n";

foreach my $version_line ( <IN> ) {
	if( $version_line =~ /VERSION/ ) {
		my @version_split = split / /, $version_line;
		if( $version_split[1] != "6.4.0.9" ) {
			print "Update is only needed for UCS 6.4.0.9; aborting script...\n";
			exit( 0 );
		}
	}
}

my $old_hostgroup_conf = "/var/opt/openit/etc/filtrator/licenseevents-hostgroups.conf";
my @new_lines;

open( IN, $old_hostgroup_conf ) || die "ERROR: Unable to read licenseevents-hostgroups.conf!\n";

my $filter_defs_scope = 0;
my $wrong_filter_def_fixed = 0;

foreach my $line ( <IN> ) {
	if( $line =~ /usergroups/ ) {
		$line =~ s/usergroups/hostgroups/g;
	}

	if( $line =~ /filter-defs/ ) {
		$filter_defs_scope = 1;
	}

	if( $filter_defs_scope and ! $wrong_filter_def_fixed and $line =~ /Report\:usergroup-license-usage/ ) {
		push @new_lines, "\t\tReport:hostgroup-license-usage()=\"\"\n";
		next;
	}

	push @new_lines, $line;
}

close( IN );

rename( $old_hostgroup_conf, "$old_hostgroup_conf.pre_2123" ) || die "ERROR: Unable to write new licenseevents-hostgroups.conf file!\n";

open( OUT, ">/var/opt/openit/etc/filtrator/licenseevents-hostgroups.conf" ) || die "ERROR: Unable to write new licenseevents-hostgroups.conf file!\n";
print OUT @new_lines;
close( OUT );

exit( 0 ); 
