#!/etc/opt/openit/perl

# Applies the following updates for licenseevents-individual-usage.conf:
# classifications object values for Report filter - var8 and var9 values change to 'undef'
# Remove Duplicate:usergroups filter process and definition
# In Concurrent:feature filter definition, removed keytype line and used_licenses in compare key

my $old_file = "/var/opt/openit/etc/filtrator/licenseevents-individual-usage.conf";
my @new_lines;

open( IN, $old_file ) || die "ERROR: Unable to read licenseevents-individual-usage.conf!\n";

my $filter_process_scope = 0;
my $filter_defs_scope = 0;

my $usergroups_filter_found = 0;
my $usergroups_filter_upper_half_removed = 0;
my $usergroups_filter_lower_half_removed = 0;

my $usergroups_def_found = 0;
my $usergroups_def_removed = 0;

my $concurrent_def_scope = 0;

my $report_def_found = 0;
my $report_classification_done = 0;

foreach my $line ( <IN> ) {
	if( $line =~ /filter-process/ ) {
		$filter_process_scope = 1;
	}
	if( $line =~ /filter-defs/ ) {
		$filter_process_scope = 0;
		$filter_defs_scope = 1;
	}

	if( $filter_process_scope and ! $usergroups_filter_found and ! $usergroups_filter_upper_half_removed and $line =~ /Duplicate\:usergroups/ ) {
		$usergroups_filter_found = 1;
		next;
	}

	if( $filter_process_scope and $usergroups_filter_found and ! $usergroups_filter_upper_half_removed and $line =~ /\{/ ) {
		$usergroups_filter_upper_half_removed = 1;
		next;
	}

	if( $filter_process_scope and $usergroups_filter_found and $usergroups_filter_upper_half_removed and ! $usergroups_filter_lower_half_removed and $line =~ /\t\t\t\t\t\t\}/ ) {
		$usergroups_filter_lower_half_removed = 1;
		next;
	}


	if( $filter_defs_scope and $line =~ /Duplicate\:usergroups/ ) {
		$usergroups_def_found = 1;
		next;
	}
	
	if( $filter_defs_scope and $usergroups_def_found and ! $usergroups_def_removed ) {
		if( $line =~ /^\t\t\}$/ ) {
			$usergroups_def_removed = 1;
		}
		next;
	}

	if( $filter_defs_scope and $line =~ /Concurrent\:feature/ ) {
		$concurrent_def_scope = 1;
	}

	if( $filter_defs_scope and $concurrent_def_scope ) {
		if( $line =~ /keytype/ ) {
			next;
		}
		if( $line =~ /compare/ ) {
			$line =~ s/used_licenses,//g;
		}
		if( $line =~ /\t\t\}/ ) {
			$concurrent_def_scope = 0;
		}
	}

	if( $filter_defs_scope and $line =~ /Report\:individual-license-usage/ ) {
		$report_def_found = 1;
	}

	if( $filter_defs_scope and $report_def_found and ! $report_classification_done and $line =~ /classifications/ ) {
		$line =~ s/var[8|9]/'undef'/g;
		$report_classification_done = 1;
	}

	push @new_lines, $line;
}

close( IN );

rename( $old_file, "$old_file.pre_2123" ) || die "ERROR: Can't create backup for licenseevents-individual-usage.conf!\n";

open( OUT, ">" . $old_file ) || die "ERROR: Can't write new licenseevents-individual-usage.conf file!\n";
print OUT @new_lines;
close( OUT );

exit( 0 ); 
