#!/etc/opt/openit/perl

# Applies the following updates for licenseevents-usergroups.conf:
# If patch 2098 is installed, Mapping:remove-zero-group will become Mapping:rename-zero-group
# Add following line to Summarize:license-usage filter definition -- set-value(String)="#9:avg=elapsed_time/duration"{}

my $old_file = "/var/opt/openit/etc/filtrator/licenseevents-usergroups.conf";
my @new_lines;

open( IN, $old_file ) || die "ERROR: Unable to read licenseevents-usergroups.conf!\n";

my $filter_defs_scope = 0;

my $summarize_def_found = 0;
my $summarize_modification_done = 0;

my $zero_group_def_scope = 0;

foreach my $line ( <IN> ) {
	if( $line =~ /filter-defs/ ) {
		$filter_defs_scope = 1;
	}

	if( $line =~ /Threshold\:remove-zero-group/ ) {
		$line =~ s/remove/rename/g;
		$line =~ s/Threshold/Mapping/g;

		if( $filter_defs_scope ) {
			$zero_group_def_scope = 1;
			push @new_lines, $line;
			next;
		}
	}

	if( $filter_defs_scope and $line =~ /Summarize\:license-usage/ ) {
		$summarize_def_found = 1;
	}

	if( $filter_defs_scope and $summarize_def_found and $line =~ /set\-value/ ) {
		$summarize_modification_done = 1;
	}

	if( $filter_defs_scope and $summarize_def_found and ! $summarize_modification_done and $line =~ /\t\t\}/ ) {
		push @new_lines, "\t\t\tset-value(String)=\"#9:avg=elapsed_time/duration\"{}\n";
		$summarize_modification_done = 1;
	}

	if( $zero_group_def_scope ) {
		if( $line =~ /\t\t\{/ ) {
			push @new_lines, $line;
		}
		if( $line =~ /\t\t\}/ ) {
			push @new_lines, "\t\t\tfilter(String)=\"Mapping\"{}\n";
			push @new_lines, "\t\t\tsimple-map(String)=\"'0'='Unmatched',' '='Unmatched'\"{}\n";
			push @new_lines, "\t\t\tsource(String)=\"var9\"{}\n";
			push @new_lines, "\t\t\ttarget(String)=\"var9\"{}\n";
			push @new_lines, $line;
			$zero_group_def_scope = 0;
		}
		next;
	}

	push @new_lines, $line;
}

close( IN );

rename( $old_file, "$old_file.pre_2123" ) || die "ERROR: Can't create backup file for licenseevents-usergroups.conf!\n";

open( OUT, ">" . $old_file ) || die "ERROR: Can't write new licenseevents-usergroups.conf file!\n";
print OUT @new_lines;
close( OUT );

exit( 0 ); 
